

set -ex



pip check
test -f ${PREFIX}/share/jupyter/nbextensions/jupyter-matplotlib/extension.js
test -f ${PREFIX}/share/jupyter/nbextensions/jupyter-matplotlib/index.js
test -f ${PREFIX}/share/jupyter/labextensions/jupyter-matplotlib/package.json
exit 0
